@@ -5,26 +5,26 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-
 #pragma once
 
-#include <QMainWindow>
 #include "ui_mainwindow.h"
+#include <QMainWindow>
 
 #include "core/types.h"
 
-namespace KGAPI2 {
-  class Job;
+namespace KGAPI2
+{
+class Job;
 }
 
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
 
-  public:
+public:
     explicit MainWindow(QWidget *parent = nullptr);
 
-  private Q_SLOTS:
+private Q_SLOTS:
     /**
      * Retrieves tokens from Google that we will use to authenticate
      * further requests
@@ -43,10 +43,8 @@ class MainWindow : public QMainWindow
      */
     void contactSelected();
 
-  private:
+private:
     Ui::MainWindow ui;
 
     KGAPI2::AccountPtr m_account;
-
 };
-
